# Papillon
A python alternative to [cummeRbund](http://compbio.mit.edu/cummeRbund/) to read and plot [Galaxy](https://usegalaxy.org/)/cuffdiff RNA-seq data 

![Preview](https://user-images.githubusercontent.com/34346930/34152979-4c3dae42-e4a8-11e7-9259-005a016edb53.png)

[![PyPI version](https://badge.fury.io/py/papillon.svg)](https://pypi.python.org/pypi/papillon)
[![Python3](https://img.shields.io/badge/python-3-blue.svg)](https://www.python.org/)
[![Pandas](https://img.shields.io/badge/python%20module-pandas-blue.svg)](https://pandas.pydata.org/)
[![Seaborn](https://img.shields.io/badge/python%20module-seaborn-blue.svg)](https://seaborn.pydata.org/)
[![Build Status](https://travis-ci.org/domenico-somma/Papillon.svg?branch=master)](https://travis-ci.org/domenico-somma/Papillon)
[![codecov](https://codecov.io/gh/domenico-somma/Papillon/branch/master/graph/badge.svg)](https://codecov.io/gh/domenico-somma/Papillon)




## Installation

You can use Papillon with any Scientific IDE, and install it using Pypi:

    pip install papillon

or Anaconda with conda-forge channel:

    conda config --add channels conda-forge
    conda install papillon

## Usage

[Quick Tutorial](https://github.com/domenico-somma/Papillon/wiki/Quick-Tutorial).

[Wiki](https://github.com/domenico-somma/Papillon/wiki).
